@@ -324,18 +324,18 @@ class S3:
 			if self.get_size(file) > 0:
 				if not self.is_parquet_file(path=file):
 					print(f'"{file}" does not appear to be a parquet file!')
-				return spark.read.load(file)
+				return spark.read.parquet(file)
 			else:
 				raise FileNotFoundError(f'"{file}" is empty!')
 
 		elif parallel:
-			return spark.read.load(path=f'{path}/part-*.parquet')
+			return spark.read.parquet(f'{path}/part-*.parquet')
 
 		else:
 			parquet_files = [file for file in files if self.is_parquet_file(path=file)]
 			result = None
 			for parquet in parquet_files:
-				data = spark.read.load(self._get_absolute_path(parquet))
+				data = spark.read.parquet(self._get_absolute_path(parquet))
 				if result is None:
 					result = data
 				else:
